Mates, you are all welcome to contribute to reaching the 5 mark.

## Contributors
- pamquale

## Documentation

### Installation
```
pip install pamqualeLabsTasks
```
### Usage
Specify the lab number and the task number to get the result.
```python
from pamqualeLabsTasks.labX import LabX
```
In the code you can call the class using the following pattern:
```python
def taskX(value):
    return LabN(value).taskX()
```

